import base64
import hashlib
import logging
from Crypto.Cipher import AES
from Crypto.Util.Padding import pad
from django.conf import settings


@staticmethod
def base64_encode(text):
    # Return the Base64 encoding of the input string
    return base64.b64encode(text.encode("utf-8")).decode("utf-8")


@staticmethod
def salt_key(token):
    salt = settings.WING_SALT_KEY or "PBKDF2"
    token = token.replace("-", "")
    return hashlib.pbkdf2_hmac("SHA256", token.encode(), salt.encode(), 65536, 32)


@staticmethod
def encrypt(key_order, token):
    try:
        # Derive the key using PBKDF2 with the token and a salt
        key = salt_key(token)

        # Define the IV (Initialization Vector) as 16 zero bytes
        iv = bytes([0] * 16)  # 16-byte IV, equivalent to the zeroed array in Java

        # Initialize AES cipher in CBC mode with PKCS7 padding
        cipher = AES.new(key, AES.MODE_CBC, iv)

        # Pad the plaintext to be a multiple of AES block size (16 bytes)
        padded_data = pad(key_order.encode("utf-8"), AES.block_size)

        # Encrypt the data
        encrypted_data = cipher.encrypt(padded_data)

        # Return the base64-encoded encrypted data
        return base64.b64encode(encrypted_data).decode("utf-8")

    except Exception as e:
        logging.error(f"Error while encrypting: {e}")
        return None

@staticmethod
def generate_txn_hash(key_order, token):

    # Step 1: Encode the key order
    encrypt_aes_256 = encrypt(base64_encode(key_order), token)

    # Step 2: Encode the encrypted string in base64
    encoded_string = base64.b64encode(encrypt_aes_256.encode()).decode("utf-8")

    # Step 3: Generate the SHA-256 hash (hex format)
    return hashlib.sha256(encoded_string.encode()).hexdigest().upper()

