from typing import List, Literal, Optional, TypedDict


# OAuth Token Response Data Class
class OAuthToken(TypedDict):
    access_token: Optional[str]
    token_type: Optional[Literal["bearer"]]
    expires_in: Optional[int]
    scope: Optional[str]


# Product Detail Data Class
class ProductDetail(TypedDict):
    product_id: str
    product_type: str
    product_qty: int
    product_unit_price: any
    currency: str


# Class data for Deep Link for payment
class PaymentRequest(TypedDict):
    order_reference_no: str
    amount: str
    currency: str
    merchant_name: str
    merchant_id: str
    item_name: str
    success_callback_url: str
    fail_callback_url: str
    schema_url: str
    txn_hash: str
    product_detail: List[ProductDetail]


class PaymentResponse(TypedDict):
    error_code: str
    amount: str
    currency: str
    error_text: str
    pre_order_id: str
    merchant_name: str
    merchant_id: str
    item_name: str
    redirect_url: str


# KHQR Data Class
class KHQRRequest(TypedDict):
    order_reference_no: str
    amount: any
    currency: str
    merchant_name: str
    merchant_id: str
    item_name: str
    txn_hash: str
    product_detail: List[ProductDetail]


class KHQRResponse(TypedDict):
    error_code: str
    amount: any
    currency: str
    khqr: str
    error_text: str
    merchant_name: str
    merchant_id: str
    item_name: str
    
    
class CheckTRXStatusRequest(TypedDict):
    order_reference_no: str
    merchant_name: str

class CheckTRXStatusResponse(TypedDict):
    error_code: str
    message: str