import logging
from typing import Optional

import httpx
from django.conf import settings

from wdg_core_payment._objects import CheckTRXStatusRequest, CheckTRXStatusResponse


class CheckTRXStatusService:
    def __init__(self):
        self.api_url = getattr(settings, "CHECK_TXN_STATUS_ENDPOINTS", None)

    def check_trx_status(
        self, trx_data: CheckTRXStatusRequest
    ) -> Optional[CheckTRXStatusResponse]:
        """Send check TRX status request and return the response."""
        with httpx.Client() as client:
            try:
                response = client.post(self.api_url, json=trx_data)
                response.raise_for_status()
                response_data = response.json()

                # Return the parsed response
                return CheckTRXStatusResponse(
                    error_code=response_data.get("error_code"),
                    message=response_data.get("message"),
                )
            except httpx.HTTPStatusError as e:
                logging.error(f"HTTP error occurred: {e}")
            except httpx.RequestError as e:
                logging.error(f"Request error occurred: {e}")
            return None
