import httpx
import logging
from typing import Optional
from django.conf import settings
from wdg_core_payment._objects import PaymentRequest, PaymentResponse


class CreateDeepLinkService:
    def __init__(self):
        self.api_url = getattr(settings, "CREATE_DEEPLINK_ENDPOINTS", None)

    def send_payment_request(
        self,
        access_token: str,
        payment_data: PaymentRequest,
    ) -> Optional[PaymentResponse]:
        """Send request and return response."""

        with httpx.Client() as client:
            try:
                headers = {
                    "Authorization": f"Bearer {access_token}",
                    "Content-Type": "application/json",
                }

                response = client.post(self.api_url, json=payment_data, headers=headers)
                response.raise_for_status()
                response_data = response.json()

                # Return the parsed response
                return PaymentResponse(
                    error_code=response_data.get("error_code"),
                    amount=response_data.get("amount"),
                    currency=response_data.get("currency"),
                    error_text=response_data.get("error_text"),
                    pre_order_id=response_data.get("pre_order_id"),
                    merchant_name=response_data.get("merchant_name"),
                    merchant_id=response_data.get("merchant_id"),
                    item_name=response_data.get("item_name"),
                    redirect_url=response_data.get("redirect_url"),
                )
            except httpx.HTTPStatusError as e:
                logging.error(f"HTTP error occurred: {e}")
            except httpx.RequestError as e:
                logging.error(f"Request error occurred: {e}")
            return None
