import base64
import hashlib

import pytest
from django.conf import settings
from django.test import TestCase

from wdg_core_payment._helper import base64_encode, encrypt, generate_txn_hash, salt_key
from wdg_core_payment.services._wing_oauth_service import OAuthService


class Base64EncodeTestCase(TestCase):
    
    def test_base64_encode(self):
        test_string = "hello world"
        expected_output = base64.b64encode(test_string.encode("utf-8")).decode("utf-8")
        self.assertEqual(base64_encode(test_string), expected_output)

    def test_salt_key(self):
        test_token = "test-token"
        salt = settings.WING_SALT_KEY.encode()
        expected_output = hashlib.pbkdf2_hmac(
            "SHA256", test_token.replace("-", "").encode(), salt, 65536, 32
        )
        self.assertEqual(salt_key(test_token), expected_output)

    def test_encrypt(self):
        test_key_order = "3.25#USD#00750315#INV04022025-001"
        test_token = "48997cfd-96a7-4ee1-b778-6123c1dafeb5"
        encrypted_data = encrypt(test_key_order, test_token)
        self.assertIsNotNone(encrypted_data)
        self.assertIsInstance(encrypted_data, str)

    def test_generate_txn_hash(self):
        test_key_order = "3.25#USD#00750315#INV04022025-001"
        test_token = "48997cfd-96a7-4ee1-b778-6123c1dafeb5"
        txn_hash = generate_txn_hash(
            test_key_order, test_token
        )
        self.assertIsNotNone(txn_hash)
        self.assertIsInstance(txn_hash, str)
        self.assertEqual(len(txn_hash), 64)
        self.assertEqual(
            "AC8532E388F0304C52F11818DAE6A5FD127BD9884D8EAD494C015EB2BE8EEA58", txn_hash
        )

    def test_get_access_token(self):
        oauth_service = OAuthService()
        token = oauth_service.get_access_token()

        # Test if the OAuth token is returned as expected
        assert token is not None
        assert token["access_token"] is not None
        assert token["token_type"] == "bearer"
        assert token["expires_in"] == 300
        assert token["scope"] == "read trust write"
